# Host keytable entry : keymap name in qemu/xen
# Only use lower case entries: all lookups are .lower()'d
keytable = {
    "ar":"ar",
    "da":"da", "dk":"da",
    "de":"de",
    "de-ch":"de-ch",
    "en-gb":"en-gb", "gb":"en-gb", "uk":"en-gb",
    "en-us":"en-us", "us":"en-us",
    "es":"es",
    "et":"et",
    "fi":"fi", "se_fi":"fi",
    "fo":"fo",
    "fr":"fr",
    "fr-be":"fr-be", "be":"fr-be",
    "fr-ca":"fr-ca",
    "fr-ch":"fr-ch", "fr_ch":"fr-ch",
    "hr":"hr",
    "hu":"hu",
    "is":"is",
    "it":"it",
    "ja":"ja", "jp106":"ja",
    "lt":"lt",
    "lv":"lv",
    "mk":"mk",
    "nl": "nl",
    "nl-be":"nl-be",
    "no":"no",
    "pl":"pl",
    "pt":"pt",
    "pt-br":"pt-br", "br":"pt-br", "br-abnt2":"pt-br",
    "ru":"ru",
    "sl":"sl",
    "sv":"sv",
    "th":"th",
    "tr":"tr",
}

